@@ -6,7 +6,6 @@ import sys
 
 import xlrd
 
-
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
@@ -20,8 +19,8 @@ class SsConverter:
         self._supported_fina_seasons = {'SCM': [2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022],
                                         'LCM': [2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022]
                                         }
-        self._fina_season_base = {'SCM': 2022,      # Validity Period: 1.9.YYYY-31.8.YYYY+1
-                                  'LCM': 2022}      # Validity Period: 1.1.XXXX-31.12.XXXX
+        self._fina_season_base = {'SCM': 2022,  # Validity Period: 1.9.YYYY-31.8.YYYY+1
+                                  'LCM': 2022}  # Validity Period: 1.1.XXXX-31.12.XXXX
         self._fina_points_table_base_times_path = os.path.join(os.path.dirname(__file__), 'fina_points_base_times_table.xls')
         self._rudolph_points_table_path = os.path.join(os.path.dirname(__file__), 'rudolph_points_table.xls')
         self._dict_style_styleid = {
@@ -275,6 +274,7 @@ class SsConverter:
         distance = float(style.split('m ')[0])
         finapts = list()
         basetime = self._finabasetimes[season_base][course][gender][1][distance][self._dict_stroke_finabasename[stroke]]
+        basetime = round(basetime, 2)  # round because str to frac is never precise
         if not basetime:
             raise ValueError('BaseTime could not be found with arguments "%s, %s, %s, %s, %s"' % (season_base, course, gender, distance, stroke))
 
@@ -322,6 +322,7 @@ class SsConverter:
         distance = float(style.split('m ')[0])
         seconds = list()
         basetime = self._finabasetimes[season_base][course][gender][1][distance][self._dict_stroke_finabasename[stroke]]
+        basetime = round(basetime, 2)  # round because str to frac is never precise
         if not basetime:
             raise ValueError('BaseTime could not be found with arguments "%s, %s, %s, %s"' % (course, gender, style, seconds))
 
@@ -353,7 +354,7 @@ class SsConverter:
 
     def get_fina_validity_period(self, course):
         if course == 'SCM':
-            return '1. Sept. %s - 31. Aug. %s' % (self._fina_season_base[course], self._fina_season_base[course]+1)
+            return '1. Sept. %s - 31. Aug. %s' % (self._fina_season_base[course], self._fina_season_base[course] + 1)
         elif course == 'LCM':
             return '1. Jan. %s - 31. Dec. %s' % (self._fina_season_base[course], self._fina_season_base[course])
         return None
@@ -464,3 +465,5 @@ if __name__ == '__main__':
     print(ssconv.get_rudolphpts_from_seconds('F', '200m Backstroke', 9, [203.87], 2009))
     print(ssconv.get_seconds_from_finapts('LCM', 'M', '100m Freestyle', 900))
     print(ssconv.get_finapts_from_seconds('SCM', 'M', '50m Freestyle', [20.24], 2020))
+
+    print(ssconv.get_finapts_from_seconds('LCM', 'F', '200m Freestyle', 112.98))
